//-----------------------------------------------------------------------------
/*
 * Description: This file contains the class AxPluginSetup
 *
 * See the file README in the main directory for a description of
 * this software, copyright information, and how to reach the author.
 *
 * Author: alex
 * Date:   15.11.2003
 *
 * Last modfied:
 *   $Author: alex $
 *   $Date: 2008-08-13 19:15:36 +0200 (Mi, 13 Aug 2008) $
 *   $Revision: 1.12 $
 */
//-----------------------------------------------------------------------------
#ifndef __AxPluginSetup_H__
#define __AxPluginSetup_H__

//-----------------------------------------------------------------------------
//     includes
//-----------------------------------------------------------------------------

//----- qt --------------------------------------------------------------------
//----- CORBA -----------------------------------------------------------------
//----- C++ -------------------------------------------------------------------
#include <string>

//----- C ---------------------------------------------------------------------
//----- AxLib -----------------------------------------------------------------
#include <Ax/Mail/Globals.h>

//----- local -----------------------------------------------------------------
//----- vdr -------------------------------------------------------------------
#include <vdr/font.h>

//----- local -----------------------------------------------------------------

//=============================================================================
//     forward declarations
//=============================================================================
class cPlugin;

//=============================================================================
//     typedefs
//=============================================================================

//=========================================================================
//     class AxPluginSettings
//=========================================================================
/** Small class to hold the settings for the plugin
*/
class AxPluginSettings
{
  public:
    //-------------------------------------------------------------------------
    //     AxPluginSettings()
    //-------------------------------------------------------------------------
    AxPluginSettings();

    //-------------------------------------------------------------------------
    //     clear()
    //-------------------------------------------------------------------------
    void clear();

    //-------------------------------------------------------------------------
    //     parseSetup()
    //-------------------------------------------------------------------------
    bool parseSetup(const char *theName, const char *theValue);

    //-------------------------------------------------------------------------
    //     storeSetup()
    //-------------------------------------------------------------------------
    void storeSetup(cPlugin *thePlugin);

    //-------------------------------------------------------------------------
    //     attributes
    //-------------------------------------------------------------------------
    int  BGCheckDelay ;
    int  BGCheckDelayMax;
    int  MLV_SortOrder;
    int  MLV_MaxMails ;
    int  MV_ViewMode  ;
    int  ConnTimeOut  ;
    std::string MailInfoCmd;
    std::string MailConvCmd;
    std::string MailSrcFile;
    std::string MailDstFile;

}; // class AxPluginSettings

//=============================================================================
//     class AxPluginSetup
//=============================================================================
class AxPluginSetup
{
  public:
    //-------------------------------------------------------------------------
    //     AxPluginSetup()
    //-------------------------------------------------------------------------
    AxPluginSetup();

    //-------------------------------------------------------------------------
    //     AxPluginSetup()
    //-------------------------------------------------------------------------
    AxPluginSetup(const AxPluginSetup &that);

    //-------------------------------------------------------------------------
    //     operator=()
    //-------------------------------------------------------------------------
    AxPluginSetup &operator=(const AxPluginSetup &that);

    //-------------------------------------------------------------------------
    //     ~AxPluginSetup()
    //-------------------------------------------------------------------------
    ~AxPluginSetup();

    //-------------------------------------------------------------------------
    //     loadAccounts()
    //-------------------------------------------------------------------------
    /** cPlugin::ConfigDirectory(myPlugin->Name())
     */
    bool loadAccounts(const std::string &theConfigFolder);

    //-------------------------------------------------------------------------
    //     saveAccounts()
    //-------------------------------------------------------------------------
    /** cPlugin::ConfigDirectory(myPlugin->Name())
     */
    bool saveAccounts(const std::string &theConfigFolder);

    //-------------------------------------------------------------------------
    //     clear()
    //-------------------------------------------------------------------------
    void clear();

  private:
    //-------------------------------------------------------------------------
    //     copyFrom()
    //-------------------------------------------------------------------------
    void copyFrom(const AxPluginSetup &that);

    //-------------------------------------------------------------------------
    //     clearAccounts()
    //-------------------------------------------------------------------------
    void clearAccounts();

    //-------------------------------------------------------------------------
    //     readKeyVal()
    //-------------------------------------------------------------------------
    bool readKeyVal(const::std::string theLine, std::string &theKey, std::string &theVal);

  public:
    //-------------------------------------------------------------------------
    //     attributes
    //-------------------------------------------------------------------------
    AxPluginSettings           Settings;
    Ax::Mail::MailBoxSetupCltn Accounts;

}; // class AxPluginSetup

#endif

